==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPolyDataMapper2D.java <==
// java wrapper for vtkPolyDataMapper2D object
//

package vtk;
import vtk.*;

public class vtkPolyDataMapper2D extends vtkMapper2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkPolyData id0);
  public void SetInputData(vtkPolyData id0)
    { SetInputData_2(id0); }

  private native long GetInput_3();
  public vtkPolyData GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLookupTable_4(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_4(id0); }

  private native long GetLookupTable_5();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_5();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLookupTable_6();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_6(); }

  private native void SetScalarVisibility_7(int id0);
  public void SetScalarVisibility(int id0)
    { SetScalarVisibility_7(id0); }

  private native int GetScalarVisibility_8();
  public int GetScalarVisibility()
    { return GetScalarVisibility_8(); }

  private native void ScalarVisibilityOn_9();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_9(); }

  private native void ScalarVisibilityOff_10();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_10(); }

  private native void SetColorMode_11(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_11(id0); }

  private native int GetColorMode_12();
  public int GetColorMode()
    { return GetColorMode_12(); }

  private native void SetColorModeToDefault_13();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_13(); }

  private native void SetColorModeToMapScalars_14();
  public void SetColorModeToMapScalars()
    { SetColorModeToMapScalars_14(); }

  private native void SetColorModeToDirectScalars_15();
  public void SetColorModeToDirectScalars()
    { SetColorModeToDirectScalars_15(); }

  private native String GetColorModeAsString_16();
  public String GetColorModeAsString()
    { return GetColorModeAsString_16(); }

  private native void SetUseLookupTableScalarRange_17(int id0);
  public void SetUseLookupTableScalarRange(int id0)
    { SetUseLookupTableScalarRange_17(id0); }

  private native int GetUseLookupTableScalarRange_18();
  public int GetUseLookupTableScalarRange()
    { return GetUseLookupTableScalarRange_18(); }

  private native void UseLookupTableScalarRangeOn_19();
  public void UseLookupTableScalarRangeOn()
    { UseLookupTableScalarRangeOn_19(); }

  private native void UseLookupTableScalarRangeOff_20();
  public void UseLookupTableScalarRangeOff()
    { UseLookupTableScalarRangeOff_20(); }

  private native void SetScalarRange_21(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_21(id0,id1); }

  private native void SetScalarRange_22(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_22(id0); }

  private native double[] GetScalarRange_23();
  public double[] GetScalarRange()
    { return GetScalarRange_23(); }

  private native void SetScalarMode_24(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_24(id0); }

  private native int GetScalarMode_25();
  public int GetScalarMode()
    { return GetScalarMode_25(); }

  private native void SetScalarModeToDefault_26();
  public void SetScalarModeToDefault()
    { SetScalarModeToDefault_26(); }

  private native void SetScalarModeToUsePointData_27();
  public void SetScalarModeToUsePointData()
    { SetScalarModeToUsePointData_27(); }

  private native void SetScalarModeToUseCellData_28();
  public void SetScalarModeToUseCellData()
    { SetScalarModeToUseCellData_28(); }

  private native void SetScalarModeToUsePointFieldData_29();
  public void SetScalarModeToUsePointFieldData()
    { SetScalarModeToUsePointFieldData_29(); }

  private native void SetScalarModeToUseCellFieldData_30();
  public void SetScalarModeToUseCellFieldData()
    { SetScalarModeToUseCellFieldData_30(); }

  private native void ColorByArrayComponent_31(int id0,int id1);
  public void ColorByArrayComponent(int id0,int id1)
    { ColorByArrayComponent_31(id0,id1); }

  private native void ColorByArrayComponent_32(String id0,int id1);
  public void ColorByArrayComponent(String id0,int id1)
    { ColorByArrayComponent_32(id0,id1); }

  private native String GetArrayName_33();
  public String GetArrayName()
    { return GetArrayName_33(); }

  private native int GetArrayId_34();
  public int GetArrayId()
    { return GetArrayId_34(); }

  private native int GetArrayAccessMode_35();
  public int GetArrayAccessMode()
    { return GetArrayAccessMode_35(); }

  private native int GetArrayComponent_36();
  public int GetArrayComponent()
    { return GetArrayComponent_36(); }

  private native int GetMTime_37();
  public int GetMTime()
    { return GetMTime_37(); }

  private native void SetTransformCoordinate_38(vtkCoordinate id0);
  public void SetTransformCoordinate(vtkCoordinate id0)
    { SetTransformCoordinate_38(id0); }

  private native long GetTransformCoordinate_39();
  public vtkCoordinate GetTransformCoordinate() {
    long temp = GetTransformCoordinate_39();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native boolean GetTransformCoordinateUseDouble_40();
  public boolean GetTransformCoordinateUseDouble()
    { return GetTransformCoordinateUseDouble_40(); }

  private native void SetTransformCoordinateUseDouble_41(boolean id0);
  public void SetTransformCoordinateUseDouble(boolean id0)
    { SetTransformCoordinateUseDouble_41(id0); }

  private native void TransformCoordinateUseDoubleOn_42();
  public void TransformCoordinateUseDoubleOn()
    { TransformCoordinateUseDoubleOn_42(); }

  private native void TransformCoordinateUseDoubleOff_43();
  public void TransformCoordinateUseDoubleOff()
    { TransformCoordinateUseDoubleOff_43(); }

  private native long MapScalars_44(double id0);
  public vtkUnsignedCharArray MapScalars(double id0) {
    long temp = MapScalars_44(id0);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void ShallowCopy_45(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_45(id0); }

  public vtkPolyDataMapper2D() { super(); }

  public vtkPolyDataMapper2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkPolyDataMapper2D.java <==
// java wrapper for vtkPolyDataMapper2D object
//

package vtk;
import vtk.*;

public class vtkPolyDataMapper2D extends vtkMapper2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkPolyData id0);
  public void SetInputData(vtkPolyData id0)
    { SetInputData_2(id0); }

  private native long GetInput_3();
  public vtkPolyData GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLookupTable_4(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_4(id0); }

  private native long GetLookupTable_5();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_5();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLookupTable_6();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_6(); }

  private native void SetScalarVisibility_7(int id0);
  public void SetScalarVisibility(int id0)
    { SetScalarVisibility_7(id0); }

  private native int GetScalarVisibility_8();
  public int GetScalarVisibility()
    { return GetScalarVisibility_8(); }

  private native void ScalarVisibilityOn_9();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_9(); }

  private native void ScalarVisibilityOff_10();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_10(); }

  private native void SetColorMode_11(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_11(id0); }

  private native int GetColorMode_12();
  public int GetColorMode()
    { return GetColorMode_12(); }

  private native void SetColorModeToDefault_13();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_13(); }

  private native void SetColorModeToMapScalars_14();
  public void SetColorModeToMapScalars()
    { SetColorModeToMapScalars_14(); }

  private native void SetColorModeToDirectScalars_15();
  public void SetColorModeToDirectScalars()
    { SetColorModeToDirectScalars_15(); }

  private native String GetColorModeAsString_16();
  public String GetColorModeAsString()
    { return GetColorModeAsString_16(); }

  private native void SetUseLookupTableScalarRange_17(int id0);
  public void SetUseLookupTableScalarRange(int id0)
    { SetUseLookupTableScalarRange_17(id0); }

  private native int GetUseLookupTableScalarRange_18();
  public int GetUseLookupTableScalarRange()
    { return GetUseLookupTableScalarRange_18(); }

  private native void UseLookupTableScalarRangeOn_19();
  public void UseLookupTableScalarRangeOn()
    { UseLookupTableScalarRangeOn_19(); }

  private native void UseLookupTableScalarRangeOff_20();
  public void UseLookupTableScalarRangeOff()
    { UseLookupTableScalarRangeOff_20(); }

  private native void SetScalarRange_21(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_21(id0,id1); }

  private native void SetScalarRange_22(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_22(id0); }

  private native double[] GetScalarRange_23();
  public double[] GetScalarRange()
    { return GetScalarRange_23(); }

  private native void SetScalarMode_24(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_24(id0); }

  private native int GetScalarMode_25();
  public int GetScalarMode()
    { return GetScalarMode_25(); }

  private native void SetScalarModeToDefault_26();
  public void SetScalarModeToDefault()
    { SetScalarModeToDefault_26(); }

  private native void SetScalarModeToUsePointData_27();
  public void SetScalarModeToUsePointData()
    { SetScalarModeToUsePointData_27(); }

  private native void SetScalarModeToUseCellData_28();
  public void SetScalarModeToUseCellData()
    { SetScalarModeToUseCellData_28(); }

  private native void SetScalarModeToUsePointFieldData_29();
  public void SetScalarModeToUsePointFieldData()
    { SetScalarModeToUsePointFieldData_29(); }

  private native void SetScalarModeToUseCellFieldData_30();
  public void SetScalarModeToUseCellFieldData()
    { SetScalarModeToUseCellFieldData_30(); }

  private native void ColorByArrayComponent_31(int id0,int id1);
  public void ColorByArrayComponent(int id0,int id1)
    { ColorByArrayComponent_31(id0,id1); }

  private native void ColorByArrayComponent_32(String id0,int id1);
  public void ColorByArrayComponent(String id0,int id1)
    { ColorByArrayComponent_32(id0,id1); }

  private native String GetArrayName_33();
  public String GetArrayName()
    { return GetArrayName_33(); }

  private native int GetArrayId_34();
  public int GetArrayId()
    { return GetArrayId_34(); }

  private native int GetArrayAccessMode_35();
  public int GetArrayAccessMode()
    { return GetArrayAccessMode_35(); }

  private native int GetArrayComponent_36();
  public int GetArrayComponent()
    { return GetArrayComponent_36(); }

  private native int GetMTime_37();
  public int GetMTime()
    { return GetMTime_37(); }

  private native void SetTransformCoordinate_38(vtkCoordinate id0);
  public void SetTransformCoordinate(vtkCoordinate id0)
    { SetTransformCoordinate_38(id0); }

  private native long GetTransformCoordinate_39();
  public vtkCoordinate GetTransformCoordinate() {
    long temp = GetTransformCoordinate_39();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean GetTransformCoordinateUseDouble_40();
  public boolean GetTransformCoordinateUseDouble()
    { return GetTransformCoordinateUseDouble_40(); }

  private native void SetTransformCoordinateUseDouble_41(boolean id0);
  public void SetTransformCoordinateUseDouble(boolean id0)
    { SetTransformCoordinateUseDouble_41(id0); }

  private native void TransformCoordinateUseDoubleOn_42();
  public void TransformCoordinateUseDoubleOn()
    { TransformCoordinateUseDoubleOn_42(); }

  private native void TransformCoordinateUseDoubleOff_43();
  public void TransformCoordinateUseDoubleOff()
    { TransformCoordinateUseDoubleOff_43(); }

  private native long MapScalars_44(double id0);
  public vtkUnsignedCharArray MapScalars(double id0) {
    long temp = MapScalars_44(id0);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ShallowCopy_45(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_45(id0); }

  public vtkPolyDataMapper2D() { super(); }

  public vtkPolyDataMapper2D(long id) { super(id); }
  public native long   VTKInit();

}
